try:
    from pymongo import MongoClient
except:
    pass


class MongoDB(object):
    """Records results to a MongoDB database

    :param uri: MongoDB server URI e.g. ``mongodb://localhost:27017``
    :type uri: str
    :param database: database name
    :type database: str
    :param collection: collection name
    :type collection: str

    .. note:: Use of this class requires the installation of the `pymongo
        module <https://pypi.python.org/pypi/pymongo>`_.
    .. seealso:: `MongoDB tutorial <https://api.mongodb.org/python/current/tutorial.html>`_
    """

    def __init__(self, uri, database, collection):
        self.uri = uri
        self.database_name = database
        self.collection_name = collection

    def write(self, results):
        client = MongoClient(self.uri)
        db = client[self.database_name]
        collection = db[self.collection_name]
        collection.insert_one(results)



"""
plumbium.recorders
==================

Module containing functions for recording results to files and databases.
"""

from __future__ import absolute_import
from .csvfile import CSVFile
from .sqldatabase import SQLDatabase
from .mongodb import MongoDB
from .stdout import StdOut
from .slack import Slack



from setuptools import setup


def readme():
    with open('README.rst') as f:
        return f.read()

setup(
    name='plumbium',
    version='0.6.4',
    packages=['plumbium', 'plumbium.recorders'],
    zip_safe=True,
    author='Jon Stutters',
    author_email='j.stutters@ucl.ac.uk',
    description='Record the inputs and outputs of scripts',
    long_description=readme(),
    url='https://github.com/jstutters/plumbium',
    install_requires=['wrapt'],
    setup_requires=['pytest-runner'],
    tests_require=['pytest'],
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: MIT License',
        'Topic :: System :: Logging'
    ]
)
